Function init_for_tests
pub fn init_for_tests()Expand description
Init logging for tests.
This is the same as init_from_env, except it uses a Once so that multiple initializations
are okay.
pub fn init_for_tests()Init logging for tests.
This is the same as init_from_env, except it uses a Once so that multiple initializations
are okay.